@@ -25,10 +25,10 @@ class OpenApiSpecDiff(object):
         print("\n\t\t\t\t\t\t\t\t\t----------------- Open API Spec Diff Tool: Completed -----------------")
 
     def parse_spec(self, spec_path):
-        # try:
-        spec = ResolvingParser(spec_path).specification
-        # except:
-        #     spec = ResolvingParser(spec_path, backend='swagger-spec-validator').specification
+        def recursion_limit_handler_none(limit, refstring, recursions):
+            return {}
+
+        spec = ResolvingParser(spec_path, recursion_limit_handler=recursion_limit_handler_none).specification
         return self.scan_input_spec(spec)
 
     def _process_nested_params(self, input_spec, info, lastkey, nested_data={}):
